==> haskell-xcffib-1.4.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcffib
version:              1.4.0
visibility:           public
id:                   xcffib-1.4.0-3TjsTL9gpgSGEZmuwSSWqd
key:                  xcffib-1.4.0-3TjsTL9gpgSGEZmuwSSWqd
license:              LicenseRef-OtherLicense
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  db23409e7eaae07642c58e4144cd13e4
exposed:              True
exposed-modules:      Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xcffib-1.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xcffib-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.4.0-3TjsTL9gpgSGEZmuwSSWqd
depends:
    attoparsec-0.14.4-DN7s9Fr9c113K5agmmE0LB base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    either-5.0.2-IsRu9KijQMsIAtixbpzC7M
    filemanip-0.3.6.3-6HMJbA8YHNo7K1IZo4MTu1 filepath-1.4.2.2
    language-python-0.5.8-5wkrkCdlMx94dlOzHUp0y7 mtl-2.2.2
    split-0.2.5-Gzu4NbNnTUj6rs5DfMztSh
    xcb-types-0.13.0-CKvroQj9HDNAY1VooFPZRA

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-1.4.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcffib
version:              1.4.0
visibility:           public
id:                   xcffib-1.4.0-LxCGnX0Jo4h6ECjuSoxDG8
key:                  xcffib-1.4.0-LxCGnX0Jo4h6ECjuSoxDG8
license:              LicenseRef-OtherLicense
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  f8408c8c0f934665a1336a5f54f4d6d0
exposed:              True
exposed-modules:      Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xcffib-1.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xcffib-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.4.0-LxCGnX0Jo4h6ECjuSoxDG8
depends:
    attoparsec-0.14.4-J9YnXPtrDPmCdtF55eYIY2 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    either-5.0.2-6p5gAAm87MFHfHElcvOcFg
    filemanip-0.3.6.3-AX6DFxhFwHfG1IYlVCwCbL filepath-1.4.2.2
    language-python-0.5.8-5wkrkCdlMx94dlOzHUp0y7 mtl-2.2.2
    split-0.2.5-IR1Zqi63dhsCAOfFAiRIkz
    xcb-types-0.13.0-CKvroQj9HDNAY1VooFPZRA

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
